qui {

clear all
u work

noi di "Sample selection"
noi ttest complete2, by(treat)

noi di "Chow test for differential response"
xi: reg complete2 treat female age ethnminor i.ses dr ra wo i.sector_ho studietijd loanexp if treatment==0
est sto control
xi: reg complete2 treat female age ethnminor i.ses dr ra wo i.sector_ho studietijd loanexp if treatment==1
est sto treat
suest treat control
noi test [treat_mean=control_mean]


keep if complete2

cap log close
log using analysis, text replace

replace age = . if age<16
//replace stud = stud/12 // in years

g info_cr0 = info_cr // store, we will redefine it later

// Variable list
global vlistc "female age ethnminor i.ses dr ra wo i.sector_ho studietijd loanexp"

// Little program to format se's
cap program drop _se
program _se
syntax varname [, Continue]
	di %9.3f _b[`varlist'] "  " _c 
	di "(" trim(string(_se[`varlist'], "%9.3f")) ")" _c
	scalar pval = 2*ttail(e(df_r), abs(_b[`varlist']/_se[`varlist']))
	if (pval<0.01) noi di "***" _c
	else if (pval<0.05) noi di "** " _c
	else if (pval<0.1) noi di "*  " _c
	else di "   " _c
	if ("`continue'"=="") noi di
end

************************************************ ANALYSIS **********************************************

// Descriptives (table 1)
noi di _n _n "Table 1"
foreach v of var female age ethnminor ses dr ra wo studietijd loanexp  {
	noi di as text "`v'" _col(15) _c
	qui ttest `v', by(treat)
	noi di as res %9.2f r(mu_1) %9.2f r(sd_1)  %9.2f r(mu_2) %9.2f r(sd_2)  %9.3f r(mu_2) - r(mu_1) %9.3f r(p)
}

// Table 2 with determinants of loan and info
xi: reg loanexp female age ethnminor i.ses dr ra wo studietijd, robust
est store loanexp
xi: reg info_cr female age ethnminor i.ses dr ra wo studietijd if treatment==0, robust
est store info
noi di _n _n "Table 2"
noi esttab _all, b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01) compress nogaps
est clear

// Table 3 with determinants of loan and info
cap program drop tab3
program tab3
args outvar
local if1 ""
local if2 "if loanexp==0"
local if3 "if loanexp==1"
local if4 "if v2==1" 
local if5 "if v2!=1"
noi di _n _n "Table 3"
forv i = 1/ 5 {
	qui xi: reg `outvar' treatment $vlistc `if`i'', robust
	eststo A`i'
	qui xi: reg `outvar' treatment `if`i'', robust
	eststo B`i'
	qui xi: reg `outvar' `if`i'', robust
	eststo C`i'
}
noi esttab A? , b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01) compress nogaps
noi esttab B? , b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01) compress nogaps
noi esttab C? , b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01) compress nogaps
est clear
end

noi tab3 xborrow
//g lnborrow = ln(tborrow) if tborrow>=200
//noi tab3 lnborrow


// First stages (table 4)	 
noi di _n _n "Table 4"
foreach v of var v14 v15 v16 v17 v18 {
	noi di as text "`v'" _col(15) _c
	qui ttest `v', by(treat)
	noi di as res %9.1f r(mu_1) %9.1f r(sd_1)  %9.1f r(mu_2) %9.1f r(sd_2)  %9.1f r(mu_2) - r(mu_1) %9.3f r(p)
	reg `v' treat
	eststo
}
//joint test, footnote table 4
suest _all
test treatment
noi di as text "Joint test p-value: " as res r(p)
est clear

// First stages (table 5)	 
noi  di _n _n "Table 5"
noi di _n _n "		      All			  LoanExp==0			 LoanExp==1"
noi di "var        mean     coeff      se       f-stat     coeff      se     f-stat    coeff      se      f-stat"
foreach v of var v14cr v15cr v16cr v17cr v18cr info_cr {
	sum `v' if treatment==0, meanonly
	noi di as text "`v'" _col(10) as res %6.2f r(mean) _c
	qui xi: reg `v' treatment $vlistc, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F) _c

	qui xi: reg `v' treatment $vlistc if loanexp==0, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F) _c

	qui xi: reg `v' treatment $vlistc if loanexp==1, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F)
}

// Effect subjectieve perceptie (suggestie ref)
preserve
keep id v*subj v*cr
drop if v14subj==.
drop v19subj
forv  i= 14 / 18 {
	rename v`i'subj vsubj`i'
	rename v`i'cr vcr`i'
} 
reshape long vcr vsubj , i(id) j(q)
xtset id
xi: xtreg  vcr vsubj i.q, fe
noi di _n _n as text "Effect aantrekkelijke voorwaarde {nee (-1), neutraal(0), ja(1)} op kans op juist recall (persoon en leenvoorwaarde Fixed Eff.): " as res %6.3f _b[vsubj]
restore

// Effect op groep te pessimistisch (table 5b)	 
noi  di _n _n "Table 5b"
noi di _n _n "		      All			       LoanExp==0			       LoanExp==1"
noi di "var        mean     coeff      se       f-stat     coeff      se     f-stat    coeff      se      f-stat"
foreach v of var v14neg v15neg v16neg v17neg v18neg {
	sum `v' if treatment==0, meanonly
	noi di as text "`v'" _col(10) as res %6.2f r(mean) _c
	qui xi: reg `v' treatment $vlistc, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F) _c

	qui xi: reg `v' treatment $vlistc if loanexp==0, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F) _c

	qui xi: reg `v' treatment $vlistc if loanexp==1, robust
	noi _se treatment, c
	qui test treatment
	noi di %9.2f r(F)
}

 
/* 

// OLS, RF and IV (full table 3)
cap program drop res
program res
syntax [if]
marksample touse
	// 1st Stage
	qui xi: reg info_cr treatment $vlistc if `touse', robust
	eststo
	noi testparm treatment
	// RF
	qui xi: reg xborrow treatment $vlistc if `touse', robust
	eststo
	// IV
	qui xi: ivreg xborrow (info_cr = treatment) $vlistc if `touse', robust
	eststo

	noi esttab, b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01)
	eststo clear
end

res
res if loanexp==0
res if loanexp==1

// redefine loaninfo

replace info_cr = 5 if treatment==1

// OLS
qui xi: reg xborrow info_cr0 $vlistc if treatment==0, robust
eststo
noi esttab, b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01)
eststo clear

// 1st Stage
qui xi: reg info_cr treatment $vlistc, robust
eststo
testparm treatment
// RF
qui xi: reg xborrow treatment $vlistc, robust
eststo
// IV
qui xi: ivreg xborrow (info_cr = treatment) $vlistc, robust
eststo
// OLS
qui xi: reg xborrow info_cr $vlistc if treatment==0, robust
eststo

noi esttab, b(%9.3f) se(%9.3f) stats(N F) star(* 0.1 ** 0.05 *** 0.01)
eststo clear

*/

cap log close
}

