clear all
use RawData12

label var complete_1 "Complete 1"
label var complete_2 "Complete 2"

recode geslacht (1 = 0 "Male") (2 = 1 "Female"), gen(female)
label var female "Female"

rename leeftijd age
label var age "Age"

rename socmil ses
label var ses "SES"

gen studyr = round((studietijd-7)/12) + 1
label var studyr "studiejaar"

rename allochtoon ethnminor
label var ethnminor "Ethnic Minority"

recode hbo_wo_2 (2 = 1 "Academic") (1 = 0 "Higher Voc."), gen(wo)
label var wo "Academic HE"

rename v25 ra

gen da1 = (v13_1>3) //debt averse1
gen da2 = (v13_2>3) //debt averse2

rename groep treatment
label var treatment "info treatment"

gen discount_rate = 0.05 if v26==2
replace discount_rate = 0.10 if v26==1 & v27==2
replace discount_rate = 0.20 if v27==1 & v28==2
replace discount_rate = 0.30 if v28==1 & v29==2
replace discount_rate = 0.40 if v29==1 & v30==2
replace discount_rate = 0.50 if v30==1 & v31==2
replace discount_rate = 0.60 if v31==1 
rename discount_rate dr
label var dr "Discount rate"

// aantrekelijkheid condities
label def laantr -1 "nee" 0 "neutraal" 1 "ja"
forv t = 6/11 {
	recode  v`t' (1 = 1) (2 = -1) (3 = 0)
	local r = `t' + 8
	ren v`t' v`r'subj
	label val v`r'subj laantr
}

recode v4 (2 = 0 "No") (1 = 1 "Yes"), gen(loanexp)
label var loanexp "Loan Experience"

//Gen variables percieved condition/info variables
scalar v14true = 500
scalar dl14 = 0
scalar du14 = 0
scalar v15true = 36
scalar dl15 = 0
scalar du15 = 0
scalar v16true = 2
scalar dl16 = 0
scalar du16 = 0
scalar v17true = 15
scalar dl17 = 2
scalar du17 = 2
scalar v18true = 3.7
scalar dl18 = .7
scalar du18 = 0.7

// rounded vars around true
gen v14r = round(v14, 100)
replace v14r = . if v14r>1000
gen v15r = round(v15/12, 1)
gen v16r = round(v16, 1)
gen v17r = round(v17, 5)
replace v17r = . if v17r>30
gen v18r = round(v18 - 3.7, 0.5) + 3.7 
replace v18r = . if v18r>6

//Too negative perceptions, potential group of compliers
gen v14neg = (v14<500)
gen v15neg = (v15<3)
gen v16neg = (v16<2)
gen v17neg = (v17<15)
gen v18neg = (v18>3.7)




//Info measures
forv t = 4/8 {
	egen sd_v1`t' = sd(v1`t')
	gen v1`t'c = 0 if v1`t'!=.
	replace v1`t'c = 1 if v1`t'>v1`t'true - .01 			///Correct info
		& v1`t'<v1`t'true + .01

	gen v1`t'cr = 0 if v1`t'!=.
	if (`t'==5) replace v1`t'cr = 1 if v1`t'r==float(3)	
	else replace v1`t'cr = 1 if v1`t'r==float(v1`t'true)	//Correct info rounded
	
	gen v1`t'c_a = 0 if v1`t'!=.
	replace v1`t'c_a = 1 if v1`t'>=v1`t'true-0.5*sd_v1`t' & ///Correct within sd
		v1`t'<= v1`t'true+0.5*sd_v1`t'  

	gen v1`t'ctm = 0 if v1`t'!=.
	replace v1`t'ctm = 1 if v1`t'>=v1`t'true - dl1`t' 	///Correct within custom
		& v1`t'<= v1`t'true + du1`t'  

	qui sum v1`t' if treatm==0
	gen v1`t'abs = abs(v1`t' - v1`t'true)				//abs deviation
	scalar sd_v1`t'C = r(sd)
	gen v1`t'sd = v1`t'abs /sd_v1`t'C if v1`t'!=.		//Standardized deviation
}




gen info = v14c + v15c + v16c + v17c + v18c
gen info_cr = v14cr + v15cr + v16cr + v17cr + v18cr
gen info_a = v14c_a + v15c_a + v16c_a + v17c_a + v18c_a
gen info_ctm = v14ctm + v15ctm + v16ctm + v17ctm + v18ctm
gen info_sd = v14sd + v15sd + v16sd + v17sd + v18sd
gen info_abs = v14abs + v15abs + v16abs + v17abs + v18abs

label var v14r "Max Loan (euro)"
label var v14c "Corr. Max Loan"
label var v15r "Max Loan Period (years)"
label var v15c "Corr. Max Loan Period"
label var v16r "Grace Period (years)"
label var v16c "Corr. Grace Period"
label var v17r "Repay Period (years)"
label var v17c "Corr. Repay Period"
label var v18r "Interest rate (%)"
label var v18c "Corr. Interest rate"
label var info_cr	"# Correct Answers"

//Gen borrowing dummy; total borrowing; Work; ECTS
g xborrow = (xapril==1|xmei==1|xjuni==1|xjuli==1)
label var xborrow "Loan"

g tborrow = april + mei + juni + juli
label var tborrow "Loan amount"
gen tborpos = tborrow if tborrow>0
recode april_werk (. = 0) if v1_2<=2
recode mei_werk (. = 0) if v1_2<=2
recode juni_werk (. = 0) if v1_2<=2
recode juli_werk (. = 0) if v1_2<=2
gen twork = april_werk + mei_werk + juni_werk + juli_werk
label var twork "Work hours"

gen xwork = (twork>0) if v1_2<=2
label var xwork "Worked"

rename totaal_ects ects
label var ects "ECTS"


// Mark sample and save file
keep if complete_1==1
g complete2 = complete_2==1 & wo!=.

keep id treatment age female ses ethnmin wo dr ects xwork twork /// 
	 xborrow tbor* loanexp ra sector_ho stud* ///
     v2 v1? v1?subj v1?cr v1?r v1?c_a info_cr v1?abs v*neg complete2 v13_1 - v14_2 da1 da2

     
compress
save work, replace 
